<?php

namespace Toplist\Toplist\Policies;

use Litepie\User\Contracts\UserPolicy;
use Toplist\Toplist\Models\Toplist;

class ToplistPolicy
{

    /**
     * Determine if the given user can view the toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Toplist $toplist)
    {
        if ($user->canDo('toplist.toplist.view') && $user->isAdmin()) {
            return true;
        }

        return $toplist->user_id == user_id() && $toplist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('toplist.toplist.create');
    }

    /**
     * Determine if the given user can update the given toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Toplist $toplist)
    {
        if ($user->canDo('toplist.toplist.edit') && $user->isAdmin()) {
            return true;
        }

        return $toplist->user_id == user_id() && $toplist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Toplist $toplist)
    {
        return $toplist->user_id == user_id() && $toplist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Toplist $toplist)
    {
        if ($user->canDo('toplist.toplist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given toplist.
     *
     * @param UserPolicy $user
     * @param Toplist $toplist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Toplist $toplist)
    {
        if ($user->canDo('toplist.toplist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
